%global srcname iraf-v216

%global git_checkout 0

%if 0%{?git_checkout}
%global commit b0f9eabba747a6cbe17fb6bc132356fa90bda141
%global commit_date 20180402
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global gitver git%{commit_date}-%{shortcommit}
%global gitrel .git%{commit_date}.%{shortcommit}
%global gittar %{name}-%{version}-%{gitver}.tar.gz
%else
%global snapshot_date 2018.03.10
%endif # 0%%{?git_checkout}

Name:           iraf
Version:        2.16.1
%if 0%{?git_checkout}
Release:        1%{?gitrel}%{?dist}
%else
Release:        1.snapshot.%{?snapshot_date}%{?dist}
%endif # 0%%{?git_checkout}
Summary:        Image Reduction and Analysis Facility

License:        BSD
URL:            http://iraf.noao.edu
%if 0%{?git_checkout}
Source0:        https://github.com/olebole/%{srcname}/archive/%{commit}.tar.gz#/%{gittar}
%else
Source0:        https://github.com/olebole/%{srcname}/archive/v%{version}+%{snapshot_date}.tar.gz
%endif # 0%%{?git_checkout}
Source1:        irafcl
Source2:        iraf.desktop
Source3:        iraf.xpm

# Debian patches
Patch0:         iraf-Use-system-libraries-when-possible.patch
Patch1:         iraf-Propagate-CFLAGS-and-debug-flag-to-xc.patch
Patch2:         iraf-Create-a-global-login.cl-in-etc.patch
Patch3:         iraf-Adjust-version-number-and-motd.patch
Patch4:         iraf-Don-t-call-back-home-on-start.patch
Patch5:         iraf-Remove-architecture-dependency-in-the-names-of-bin-subdir.patch
Patch6:         iraf-Separate-NOAO-and-dev-packages.patch
Patch7:         iraf-Add-new-architectures.patch
Patch8:         iraf-Set-defaults-for-zgtenv.patch
Patch9:         iraf-Use-O_RDONLY-in-open-calls.patch
#Patch10:        iraf-Run-tests-from-installed-iraf.patch

# General requirements
BuildRequires:  desktop-file-utils
BuildRequires:  gcc
BuildRequires:  flex
BuildRequires:  make
# Required development libraries
BuildRequires:  cfitsio-devel
BuildRequires:  curl-devel
BuildRequires:  expat-devel
BuildRequires:  ncurses-devel
BuildRequires:  readline-devel
# We need basic perl for the tests
BuildRequires:  perl-interpreter

# No IRAF on big endian architectures, not supported by upstream
ExcludeArch:    ppc64 s390x

%description
IRAF is the "Image Reduction and Analysis Facility". The main IRAF distribution
includes a good selection of programs for general image processing and
graphics, plus a large number of programs for the reduction and analysis of
optical and IR astronomy data (the "noao" packages). 
Other external or layered packages are available for applications such as data
acquisition or handling data from other observatories and wavelength regimes
such as the Hubble Space Telescope (optical), EUVE (extreme ultra-violet),
or ROSAT and AXAF or Chandra (X-ray). These external packages are distributed
separately from the main IRAF distribution but can be easily installed.
The IRAF system also includes a complete programming environment for scientific
applications, which includes a programmable Command Language scripting facility,
the IMFORT Fortran/C programming interface, and the full SPP/VOS programming
environment in which the portable IRAF system and all applications are written. 

This package is a build of the fork from Ole Streicher (olebole), who replaced
or removed non-free codes as well as copies of bundled libraries from the
original source.

%prep
%if 0%{?git_checkout}
%autosetup -p 1 -n %{srcname}-%{commit}
%else
%autosetup -p 1 -n %{srcname}-%{version}-%{snapshot_date}
%endif # 0%%{?git_checkout}

# Set proper libdir
sed -i "s,__LIBDIR__,%{buildroot}%{_libdir},g" test/run_tests
sed -i "s,__LIBDIR__,%{_libdir},g" unix/hlib/f77.sh
sed -i "s,__LIBDIR__,%{_libdir},g" unix/os/zgtenv.c
sed -i "s,__LIBDIR__,%{_libdir},g" %{SOURCE1}
# Specify that this is a Fedora build of IRAF
sed "s/__VERSION__/%{?fedora}/" -i unix/hlib/zzsetenv.def
sed "s/__DATE__/(Build: $(date -uR))/g" -i unix/hlib/zzsetenv.def

%build
export iraf=$(pwd)/
export host=${iraf}/unix/
BUILD_TMP=${iraf}/irafbuild
#export HOME=$BUILD_TMP
export IRAFARCH=$(sh ./unix/hlib/irafarch.sh)
mkdir -p ${BUILD_TMP}
./install -v --term xterm \
	--bindir ${BUILD_TMP}/bin \
	--cache ${BUILD_TMP}/cache \
	--imdir ${BUILD_TMP}/imdir \
	--root ${iraf} < /dev/null || true
cp unix/f2c/libf2c/f2c.h include/

make ${IRAFARCH}
make sysgen

%check
PATH=%{buildroot}%{_bindir}:%{buildroot}%{_libdir}/iraf/bin:${PATH} ./test/run_tests

%install
# IRAF has no proper installation routine, we have to copy stuff manually...
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_includedir}
mkdir -p %{buildroot}%{_sysconfdir}/iraf
mkdir -p %{buildroot}%{_libdir}/iraf/{bin,dev,extern,lib,local,math,noao,pkg,sys,unix/{bin,hlib}}
mkdir -p %{buildroot}%{_libdir}/iraf/pkg/{bench,cl,dataio,dbms,ecl,images,language,lists,obsolete,plot,proto,system,utilities,xtools}
mkdir -p %{buildroot}%{_libdir}/iraf/noao/{artdata,astcat,astutil,bin,digiphot,imred,lib,mtlocal,nproto,obsutil,onedspec/scombine,rv,twodspec/{apextract,longslit}}
mkdir -p %{buildroot}%{_libdir}/iraf/noao/digiphot/{apphot,daophot,photcal,ptools}
mkdir -p %{buildroot}%{_libdir}/iraf/noao/imred/{bias,ccdred,crutil,dtoi,generic,irred,quadred/{ccdproc,quad}}
# Binaries
install -D -m 755 bin/*.e %{buildroot}%{_libdir}/iraf/bin
install -D -m 755 unix/bin/*.e %{buildroot}%{_libdir}/iraf/unix/bin
# Libraries
install -D -m 755 bin/lib*.a %{buildroot}%{_libdir}/iraf/bin
install -D -m 755 bin/libmain.o %{buildroot}%{_libdir}/iraf/bin
install -D -m 755 unix/bin/lib*.a %{buildroot}%{_libdir}/iraf/unix/bin
# Header
cp -r include %{buildroot}%{_libdir}/iraf/
cp lib/*.{h,inc} %{buildroot}%{_libdir}/iraf/lib
cp -r lib/{math,pkg,sysruk.x} %{buildroot}%{_libdir}/iraf/lib
# hlib
cp unix/hlib/*.{h,inc,sf} %{buildroot}%{_libdir}/iraf/unix/hlib
cp unix/hlib/f77.sh %{buildroot}%{_libdir}/iraf/unix/hlib
cp -r unix/hlib/libc %{buildroot}%{_libdir}/iraf/unix/hlib
# NOAO files
install -D -m 755 noao/bin/*.e %{buildroot}%{_libdir}/iraf/noao/bin
install -D -m 755 noao/bin/lib*.a %{buildroot}%{_libdir}/iraf/noao/bin
cp noao/lib/*.{h,inc} %{buildroot}%{_libdir}/iraf/noao/lib

# libpkg.a files
for f in $(find . -name libpkg.a) ; do \
	install -D -m 755 $f %{buildroot}%{_libdir}/iraf/$f ; \
done

for f in $(find . -name \*.hlp \
            -o -name \*.hd \
            -o -name \*.men \
            -o -name \*.cl \
            -o -name \*.par \
            -o -name \*.key \
            -o -name \*.def \
            -o -name \*.dat \
            -o -name \*.gui \
            -o -name \*.pkg \
            -o -name \*.mip \
            -o -name \*.fits \
	    -o -path ./dev/\* | \
	    cut -c3-) \
            unix/hlib/motd* \
            lib/syserrmsg lib/syshelpdir lib/scr/help.html ; do \
install -p -D -m 644 $f %{buildroot}%{_libdir}/iraf/$f ; \
done

> %{buildroot}%{_libdir}/iraf/extern/.zzsetenv.def
mv %{buildroot}%{_libdir}/iraf/unix/hlib/login.cl %{buildroot}%{_sysconfdir}/iraf/
mv %{buildroot}%{_libdir}/iraf/unix/hlib/motd.etc %{buildroot}%{_sysconfdir}/iraf/motd
mv %{buildroot}%{_libdir}/iraf/dev/irafhosts %{buildroot}%{_sysconfdir}/iraf/
rm -f %{buildroot}%{_libdir}/iraf/dev/hosts %{buildroot}%{_libdir}/iraf/dev/uhosts
rm -rf %{buildroot}%{_libdir}/iraf/unix/f2c
echo '# HOSTS -- IRAF local network host table.' > %{buildroot}%{_sysconfdir}/iraf/hosts
for f in unix/hlib/util.sh \
         unix/hlib/mkiraf.sh unix/hlib/mkmlist.sh \
         unix/hlib/irafarch.sh ; do \
  install -p -D -m 755 $f %{buildroot}%{_libdir}/iraf/$f ; \
done

ln -sf %{_libdir}/iraf/unix/hlib/extern.pkg %{buildroot}%{_sysconfdir}/iraf/extern.pkg
ln -sf %{_libdir}/iraf/unix/hlib/hosts %{buildroot}%{_sysconfdir}/iraf/hosts
ln -sf %{_libdir}/iraf/dev/irafhosts %{buildroot}%{_sysconfdir}/iraf/irafhosts
ln -sf %{_libdir}/iraf/unix/bin/sgidispatch.e %{buildroot}%{_bindir}/sgidispatch
ln -sf %{_libdir}/iraf/unix/bin/generic.e %{buildroot}%{_bindir}/generic
ln -sf %{_libdir}/iraf/unix/bin/mkpkg.e %{buildroot}%{_bindir}/mkpkg
ln -sf %{_libdir}/iraf/unix/bin/xc.e %{buildroot}%{_bindir}/xc
ln -sf %{_libdir}/iraf/unix/bin/xyacc.e %{buildroot}%{_bindir}/xyacc
ln -sf %{_libdir}/iraf/unix/hlib/libc/iraf.h %{buildroot}%{_includedir}/iraf.h

# Install launcher script, desktop file and icon
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}
install -D -m 755 %{SOURCE1} %{buildroot}%{_bindir}
install -D -m 644 %{SOURCE3} %{buildroot}%{_datadir}/pixmaps/iraf.xpm

%files
%{_bindir}/*
%{_datadir}/applications/iraf.desktop
%{_datadir}/pixmaps/iraf.xpm
%{_includedir}/iraf.h
%{_libdir}/iraf
%{_sysconfdir}/iraf


%changelog
* Tue Jan  2 2018 Christian Dersch <lupinix@fedoraproject.org> 2.16.1-1
- initial package
